@@ -419,39 +419,6 @@ ImgSaveStat ImgSaver::saveImage( QImage *image, const KURL& filename, const QStr
 }
 
 
-
-
-
-ImgSaveStat ImgSaver::savePreview( QImage *image, const QCString& scannerName )
-{
-   if( !image ||  image->isNull() )
-      return( ISS_ERR_PARAM );
-
-   QString format = findFormat( PT_PREVIEW );
-
-   ImgSaveStat stat = ISS_ERR_FORMAT_NO_WRITE;
-
-   QString previewfile = Previewer::previewFile( scannerName );
-   if( ! format.isEmpty() )
-   {
-      // Previewfile always comes absolute
-      stat = save( image, previewfile, format, "" );
-   }
-#if 0  /* preview file name is not longer needed in config file */
-   if( stat == ISS_OK )
-   {
-      KConfig *konf = KGlobal::config ();
-      konf->setGroup( scannerName );
-
-      konf->writeEntry( OP_PREVIEW_FILE,   previewfile );
-      konf->writeEntry( OP_PREVIEW_FORMAT, format );
-      konf->sync();
-   }
-#endif
-
-   return( stat );
-}
-
 /*
  * findFormat does all the stuff with the dialog.
  */
@@ -801,8 +768,8 @@ bool ImgSaver::renameImage( const KURL& fromUrl, KURL& toUrl, bool askExt,  QWid
 	 s = i18n("The filename you supplied has no file extension.\nShould the correct one be added automatically? ");
 	 s += i18n( "That would result in the new filename: %1" ).arg( fName);
 
-	 result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension missing"),
-					     KStdGuiItem::yes(), KStdGuiItem::no(),
+	 result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension Missing"),
+					     i18n("Add Extension"), i18n("Do Not Add"),
 					     "AutoAddExtensions" );
       }
 
@@ -898,8 +865,8 @@ bool ImgSaver::copyImage( const KURL& fromUrl, const KURL& toUrl, QWidget *overW
       s = i18n("The filename you supplied has no file extension.\nShould the correct one be added automatically? ");
       s += i18n( "That would result in the new filename: %1" ).arg( fName);
 
-      result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension missing"),
-					  KStdGuiItem::yes(), KStdGuiItem::no(),
+      result = KMessageBox::questionYesNo(overWidget, s, i18n( "Extension Missing"),
+					  i18n("Add Extension"), i18n("Do Not Add"),
 					  "AutoAddExtensions" );
 
       if( result == KMessageBox::Yes )
@@ -915,8 +882,8 @@ bool ImgSaver::copyImage( const KURL& fromUrl, const KURL& toUrl, QWidget *overW
        {
 	   KMessageBox::error( overWidget, i18n("Format changes of images are currently not supported."),
 			       i18n("Wrong Extension Found" ));
+	   return(false);
        }
-      return(false);
    }
 
    KIO::Job *copyjob = KIO::copy( fromUrl, targetUrl, false );
