@@ -58,7 +58,7 @@ PMObject* createNewPrism( PMPart* part )
    return new PMPrism( part );
 }
 
-PMDefinePropertyClass( PMPrism, PMProperty );
+PMDefinePropertyClass( PMPrism, PMPrismProperty );
 PMDefineEnumPropertyClass( PMPrism, PMPrism::SplineType, PMSplineTypeProperty );
 PMDefineEnumPropertyClass( PMPrism, PMPrism::SweepType, PMSweepTypeProperty );
 
@@ -102,20 +102,20 @@ protected:
       PMVector v = var.vectorData( );
       v.resize( 2 );
 
-      for( i = 0; i < m_index[0] && sit != list.end( ); i++ )
+      for( i = 0; i < m_index[0] && sit != list.end( ); ++i )
          ++sit;
       // expand the list if necessary
-      for( ; i < m_index[0]; i++ )
+      for( ; i < m_index[0]; ++i )
          list.insert( sit, QValueList< PMVector >( ) );
       if( sit == list.end( ) )
          sit = list.insert( sit, QValueList< PMVector >( ) );
 
       QValueList<PMVector>::Iterator it = ( *sit ).begin( );
 
-      for( i = 0; i < m_index[1] && it != ( *sit ).end( ); i++ )
+      for( i = 0; i < m_index[1] && it != ( *sit ).end( ); ++i )
          ++it;
       // expand the list if necessary
-      for( ; i < m_index[1]; i++ )
+      for( ; i < m_index[1]; ++i )
          ( *sit ).insert( it, v );
       if( it == ( *sit ).end( ) )
          it = ( *sit ).insert( it, v );
@@ -157,7 +157,7 @@ PMPrism::PMPrism( PMPart* part )
    int i;
    QValueList<PMVector> p;
 
-   for( i = 0; i < defaultNumberOfPoints; i++ )
+   for( i = 0; i < defaultNumberOfPoints; ++i )
       p.append( defaultPoint[i] );
    m_points.append( p );
    m_splineType = defaultSplineType;
@@ -279,13 +279,13 @@ PMMetaObject* PMPrism::metaObject( ) const
       s_pMetaObject = new PMMetaObject( "Prism", Base::metaObject( ),
                                         createNewPrism );
       s_pMetaObject->addProperty(
-         new PMProperty( "sturm", &PMPrism::setSturm, &PMPrism::sturm ) );
+         new PMPrismProperty( "sturm", &PMPrism::setSturm, &PMPrism::sturm ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "open", &PMPrism::setOpen, &PMPrism::open ) );
+         new PMPrismProperty( "open", &PMPrism::setOpen, &PMPrism::open ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "height1", &PMPrism::setHeight1, &PMPrism::height1 ) );
+         new PMPrismProperty( "height1", &PMPrism::setHeight1, &PMPrism::height1 ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "height2", &PMPrism::setHeight2, &PMPrism::height2 ) );
+         new PMPrismProperty( "height2", &PMPrism::setHeight2, &PMPrism::height2 ) );
 
       PMSplineTypeProperty* p = new PMSplineTypeProperty(
          "splineType", &PMPrism::setSplineType, &PMPrism::splineType );
@@ -453,6 +453,8 @@ void PMPrism::createViewStructure( )
    if( s_sSteps == 0 )
       s_sSteps = c_defaultPrismSSteps;
 
+   int sSteps = (int)( ( (float)s_sSteps / 2 ) * ( displayDetail( ) + 1 ) );
+
    // calculate number of points and lines of the view structure
    QValueList< QValueList<PMVector> >::ConstIterator spit = m_points.begin( );
    int np = 0;
@@ -477,8 +479,8 @@ void PMPrism::createViewStructure( )
    }
 
    int nl = 0;
-   nl = np * s_sSteps * 3;
-   np *= s_sSteps * 2;
+   nl = np * sSteps * 3;
+   np *= sSteps * 2;
 
    if( m_pViewStructure )
    {
@@ -527,7 +529,7 @@ void PMPrism::createViewStructure( )
       it4 = it3; ++it4;
       PMSplineSegment s;
 
-      for( i = 0; i < ns; i++ )
+      for( i = 0; i < ns; ++i )
       {
          switch( m_splineType )
          {
@@ -551,7 +553,7 @@ void PMPrism::createViewStructure( )
                break;
             case BezierSpline:
                s.calculateBezier( *it1, *it2, *it3, *it4 );
-               for( j = 0; j < 4; j++ )
+               for( j = 0; j < 4; ++j )
                {
                   ++it1;
                   ++it2;
@@ -564,16 +566,16 @@ void PMPrism::createViewStructure( )
       }
 
       // create the line array
-      int vp = ns * s_sSteps;
-      for( i = 0; i < vp - 1; i++ )
+      int vp = ns * sSteps;
+      for( i = 0; i < vp - 1; ++i )
          lines[lb+i] = PMLine( pb + i, pb + i + 1 );
       lines[lb+vp-1] = PMLine( pb, pb + vp - 1 );
       lb += vp;
-      for( i = 0; i < vp - 1; i++ )
+      for( i = 0; i < vp - 1; ++i )
          lines[lb+i] = PMLine( pb + vp + i, pb + vp + i + 1 );
       lines[lb+vp-1] = PMLine( pb + vp, pb + vp + vp - 1 );
       lb += vp;
-      for( i = 0; i < vp; i++ )
+      for( i = 0; i < vp; ++i )
          lines[lb+i] = PMLine( pb + i, pb + vp + i );
       lb += vp;
 
@@ -581,11 +583,11 @@ void PMPrism::createViewStructure( )
       PMVector point2( 2 ), point3;
       QValueList<PMSplineSegment>::Iterator sit = segments.begin( );
       int pi = 0;
-      double poffset = 1.0 / s_sSteps;
+      double poffset = 1.0 / sSteps;
 
       for( i = 0; i < ns; ++i, ++sit )
       {
-         for( j = 0; j < s_sSteps; j++ )
+         for( j = 0; j < sSteps; ++j )
          {
             point2 = ( *sit ).point( poffset * j );
             if( m_sweepType == LinearSweep )
@@ -605,7 +607,7 @@ void PMPrism::createViewStructure( )
                points[pb+pi] = PMPoint( point3 * m_height1 );
                points[pb+pi+vp] = PMPoint( point3 * m_height2 );
             }
-            pi++;
+            ++pi;
          }
       }
       pb += vp * 2;
@@ -629,18 +631,18 @@ void PMPrism::controlPoints( PMControlPointList& list )
 
    PM2DControlPoint* cp;
 
-   for( it1 = m_points.begin( ), i1 = 0; it1 != m_points.end( ); ++it1, i1++ )
+   for( it1 = m_points.begin( ), i1 = 0; it1 != m_points.end( ); ++it1, ++i1 )
    {
       if( m_splineType != BezierSpline )
       {
          int refb = ( *it1 ).count( ) - 1;
          if( m_splineType == CubicSpline )
-            refb--;
+            --refb;
          it2 = ( *it1 ).begin( );
          PM2DControlPoint* firstPoint = 0;
          PM2DControlPoint* secondPoint = 0;
 
-         for( i2 = 0; it2 != ( *it1 ).end( ); ++it2, i2++ )
+         for( i2 = 0; it2 != ( *it1 ).end( ); ++it2, ++i2 )
          {
             cp = new PM2DControlPoint( *it2, PM2DControlPoint::PM2DXZ, i2,
                                        i18n( "Point %1.%2" ).arg( i1 + 1 ).arg( i2 + 1 ) );
@@ -662,7 +664,7 @@ void PMPrism::controlPoints( PMControlPointList& list )
             list.append( cp );
 
             if( ( m_splineType != BezierSpline ) && ( i2 == refb ) )
-               i2++;
+               ++i2;
          }
       }
       else
@@ -672,7 +674,7 @@ void PMPrism::controlPoints( PMControlPointList& list )
          PM2DControlPoint* lastPoint = 0;
          PM2DControlPoint* startPoint = 0;
 
-         for( i2 = 0; it2 != ( *it1 ).end( ); ++it2, i2++ )
+         for( i2 = 0; it2 != ( *it1 ).end( ); ++it2, ++i2 )
          {
             int i2mod4 = i2 % 4;
             cp = new PM2DControlPoint( *it2, PM2DControlPoint::PM2DXZ, i2,
@@ -695,7 +697,7 @@ void PMPrism::controlPoints( PMControlPointList& list )
             list.append( cp );
 
             if( i2mod4 == 2 )
-               i2++;
+               ++i2;
          }
          if( lastPoint )
             lastPoint->setBasePoint( startPoint );
@@ -841,15 +843,15 @@ void PMPrism::splitSegment( const PMControlPointList& /*cp*/,
 
    QPtrListIterator<PMVector> it1( cpViewPosition );
    QPtrListIterator<PMVector> it2( cpViewPosition );
-   for( i = 0; i < 2; i++ ) ++it1;
-   for( i = 0; i < 3; i++ ) ++it2;
+   for( i = 0; i < 2; ++i ) ++it1;
+   for( i = 0; i < 3; ++i ) ++it2;
 
    QValueList< QValueList<PMVector> >::Iterator spit = m_points.begin( );
    for( spnr = 0; spit != m_points.end( ); ++spit, ++spnr )
    {
       int nump = ( *spit ).count( );
       bool first = true;
-      for( pnr = 0; pnr < nump; pnr++ )
+      for( pnr = 0; pnr < nump; ++pnr )
       {
          bool skip = false;
          switch( m_splineType )
@@ -911,14 +913,14 @@ void PMPrism::splitSegment( const PMControlPointList& /*cp*/,
    QValueList<PMVector>::Iterator it = newSubPoints.at( ( unsigned ) ns );
    PMVector p[4];
    QValueList<PMVector>::Iterator hit = it, eit = newSubPoints.end( );
-   eit--;
+   --eit;
 
    // calculate the spline segment
    PMSplineSegment segment;
    switch( m_splineType )
    {
       case LinearSpline:
-         for( i = 0; i < 2; i++ )
+         for( i = 0; i < 2; ++i )
          {
             p[i] = *hit;
             ++hit;
@@ -929,21 +931,21 @@ void PMPrism::splitSegment( const PMControlPointList& /*cp*/,
          break;
       case QuadraticSpline:
          --hit;
-         for( i = 0; i < 3; i++ )
+         for( i = 0; i < 3; ++i )
          {
             p[i] = *hit;
             ++hit;
             if( hit == newSubPoints.end( ) )
             {
                hit = newSubPoints.begin( );
-               hit++;
+               ++hit;
             }
          }
          segment.calculateQuadratic( p[0], p[1], p[2] );
          break;
       case CubicSpline:
          --hit;
-         for( i = 0; i < 4; i++ )
+         for( i = 0; i < 4; ++i )
          {
             if( hit == eit )
             {
@@ -951,7 +953,7 @@ void PMPrism::splitSegment( const PMControlPointList& /*cp*/,
                ++hit;
                p[i] = *hit;
                hit = eit;
-               i++;
+               ++i;
                if( i < 4 )
                   p[i] = *hit;
             }
@@ -962,7 +964,7 @@ void PMPrism::splitSegment( const PMControlPointList& /*cp*/,
          segment.calculateCubic( p[0], p[1], p[2], p[3] );
          break;
       case BezierSpline:
-         for( i = 0; i < 4; i++ )
+         for( i = 0; i < 4; ++i )
          {
             p[i] = *hit;
             ++hit;
@@ -1017,7 +1019,7 @@ void PMPrism::joinSegments( const PMControlPointList& /*cp*/,
    PMVector dist( 2 );
 
    QPtrListIterator<PMVector> it1( cpViewPosition );
-   for( i = 0; i < 2; i++ ) ++it1;
+   for( i = 0; i < 2; ++i ) ++it1;
 
    int minp = 0;
    switch( m_splineType )
@@ -1041,7 +1043,7 @@ void PMPrism::joinSegments( const PMControlPointList& /*cp*/,
    {
       int nump = ( *spit ).count( );
 
-      for( pnr = 0; pnr < nump; pnr++ )
+      for( pnr = 0; pnr < nump; ++pnr )
       {
          bool skip = false;
          switch( m_splineType )
@@ -1133,7 +1135,7 @@ void PMPrism::setSSteps( int s )
       s_sSteps = s;
    else
       kdDebug( PMArea ) << "PMPrism::setSSteps: S must be greater than 0\n";
-   s_parameterKey++;
+   ++s_parameterKey;
 }
 
 QValueList<PMVector> PMPrism::expandedPoints( const QValueList<PMVector>& p ) const
@@ -1147,11 +1149,11 @@ QValueList<PMVector> PMPrism::expandedPoints( const QValueList<PMVector>& p ) co
       case LinearSpline:
          break;
       case QuadraticSpline:
-         refa++;
+         ++refa;
          break;
       case CubicSpline:
-         refa++;
-         refb--;
+         ++refa;
+         --refb;
          break;
       case BezierSpline:
          refb = refb / 3 * 4;
@@ -1173,7 +1175,7 @@ QValueList<PMVector> PMPrism::expandedPoints( const QValueList<PMVector>& p ) co
          if( ( i % 3 ) == 0 )
          {
             it2 = it1;
-            it2++;
+            ++it2;
             it3 = it2;
             if( it3 == result.end( ) )
                it3 = result.begin( );
