@@ -56,8 +56,8 @@ PMObject* createNewSphereSweep( PMPart* part )
    return new PMSphereSweep( part );
 }
 
-int PMSphereSweep::s_rSteps = 8;//c_defaultSphereSweepRSteps;
-int PMSphereSweep::s_sSteps = 4;//c_defaultSphereSweepSSteps;
+int PMSphereSweep::s_rSteps = c_defaultSphereSweepRSteps;
+int PMSphereSweep::s_sSteps = c_defaultSphereSweepSSteps;
 int PMSphereSweep::s_parameterKey = 0;
 
 
@@ -342,33 +342,37 @@ void PMSphereSweep::createViewStructure( )
    int numSpheres = m_points.size( );
    m_segments.clear( );
 
+   int rSteps = (int)( ( (float)s_rSteps / 2 ) * ( displayDetail( ) + 1 ) );
+   int sSteps = (int)( ( (float)s_sSteps / 2 ) * ( displayDetail( ) + 1 ) );
+
    switch ( m_splineType )
    {
       case LinearSpline:
          numSegments = numSpheres - 1;
-         setLinear( );
+         setLinear( sSteps );
          break;
       case BSpline:
          numSegments = numSpheres - 3;
-         setCurved( false );
+         setCurved( false, sSteps );
          break;
       case CubicSpline:
          numSegments = numSpheres - 3;
-         setCurved( true );
+         setCurved( true, sSteps );
          break;
    }
+
    //Calculates sphere points
-   int numPoints = ( ( s_rSteps * ( s_rSteps - 2 ) ) + 2 ) *
+   int numPoints = ( ( rSteps * ( rSteps - 2 ) ) + 2 ) *
                    ( numSegments + 1 );
    //Calculates segments points
-   numPoints += ( s_rSteps * s_sSteps ) * numSegments;
+   numPoints += ( rSteps * sSteps ) * numSegments;
 
    //Calculates sphere lines
-   int numLines = ( s_rSteps * ( s_rSteps + s_rSteps - 3 ) ) *
+   int numLines = ( rSteps * ( rSteps + rSteps - 3 ) ) *
                   ( numSegments + 1 );
    //Calculates segments lines
-   numLines += ( ( s_sSteps * s_rSteps ) +
-                 ( ( s_sSteps - 1 ) * s_rSteps ) ) * numSegments;
+   numLines += ( ( sSteps * rSteps ) +
+                 ( ( sSteps - 1 ) * rSteps ) ) * numSegments;
 
    if ( !m_pViewStructure )
    {
@@ -385,38 +389,38 @@ void PMSphereSweep::createViewStructure( )
    m_nextPoint = m_nextLine = 0;
 
    PMVector v1, v2;
-   double rotval = M_PI / ( s_rSteps / 2 );
+   double rotval = M_PI / ( rSteps / 2 );
 
-   createSphere( m_segments[0].points[0], m_segments[0].radii[0] );
+   createSphere( m_segments[0].points[0], m_segments[0].radii[0], rSteps );
    for ( int i = 0; i < numSegments; ++i )
    {
-      for ( int j = 0; j < s_sSteps; ++ j )
+      for ( int j = 0; j < sSteps; ++ j )
       {
-         v1 = m_segments[i].points[s_sSteps] - m_segments[i].points[0];
+         v1 = m_segments[i].points[sSteps] - m_segments[i].points[0];
          v1 = PMVector::cross( m_segments[i].direction[j], v1.orthogonal( ) );
          v1 = ( v1 * ( 1 / v1.abs( ) ) ) * m_segments[i].radii[j];
 
-         for ( int k = 0; k < s_rSteps; ++k )
+         for ( int k = 0; k < rSteps; ++k )
          {
             v2 = PMMatrix::rotation( m_segments[i].direction[j],
                                      ( rotval * k ) ) * v1;
             points[m_nextPoint++] = PMPoint( v2 + m_segments[i].points[j] );
-            if ( k < ( s_rSteps - 1 ) )
+            if ( k < ( rSteps - 1 ) )
                lines[m_nextLine++] = PMLine(
                   m_nextPoint - 1, m_nextPoint );
             else
                lines[m_nextLine++] = PMLine(
-                  m_nextPoint - 1, m_nextPoint - s_rSteps );
+                  m_nextPoint - 1, m_nextPoint - rSteps );
 
-            if ( j < ( s_sSteps - 1 ) )
+            if ( j < ( sSteps - 1 ) )
             {
                lines[m_nextLine++] = PMLine(
-                  m_nextPoint - 1, m_nextPoint + ( s_rSteps - 1 ) );
+                  m_nextPoint - 1, m_nextPoint + ( rSteps - 1 ) );
             }
          }
       }
-      createSphere( m_segments[i].points[s_sSteps - 1],
-                    m_segments[i].radii[s_sSteps - 1] );
+      createSphere( m_segments[i].points[sSteps - 1],
+                    m_segments[i].radii[sSteps - 1], rSteps );
    }
 }
 
@@ -426,7 +430,7 @@ void PMSphereSweep::controlPoints( PMControlPointList& list )
    QValueList<double>::Iterator it2;
    int i, nr;
 
-   for( it = m_points.begin( ), it2 = m_radii.begin( ), nr = 1;
+   for( it = m_points.begin( ), it2 = m_radii.begin( ), nr = 1, i = 0;
         it != m_points.end( ) && it2 != m_radii.end( ); ++it, ++it2, ++nr )
    {
       PM3DControlPoint* p = new PM3DControlPoint( *it, i++,
@@ -720,7 +724,7 @@ void PMSphereSweep::setSSteps( int s )
    s_parameterKey++;
 }
 
-void PMSphereSweep::setLinear( )
+void PMSphereSweep::setLinear( int sSteps )
 {
    int numsegments = ( m_points.size( ) - 1 );
 
@@ -733,11 +737,11 @@ void PMSphereSweep::setLinear( )
       seg.points.clear( );
       seg.radii.clear( );
       seg.direction.clear( );
-      diff = ( m_points[i + 1] - m_points[i] ) / ( s_sSteps - 1.0 );
-      raddif = ( m_radii[i + 1] - m_radii[i] ) / ( s_sSteps - 1.0 );
+      diff = ( m_points[i + 1] - m_points[i] ) / ( sSteps - 1.0 );
+      raddif = ( m_radii[i + 1] - m_radii[i] ) / ( sSteps - 1.0 );
       angle = diff * ( 1 / diff.abs( ) );
 
-      for ( int j = 0; j < s_sSteps; ++j )
+      for ( int j = 0; j < sSteps; ++j )
       {
          seg.points.append( m_points[i] + ( diff * j ) );
          seg.radii.append( m_radii[i] + ( raddif * j ) );
@@ -747,12 +751,12 @@ void PMSphereSweep::setLinear( )
    }
 }
 
-void PMSphereSweep::setCurved( bool cubic )
+void PMSphereSweep::setCurved( bool cubic, int sSteps )
 {
    int numsegments = ( m_points.size( ) - 3 );
    PMVector centres[4];
    PMVector vtr;
-   double divs = 1.0 / ( s_sSteps - 1.0 );
+   double divs = 1.0 / ( sSteps - 1.0 );
    double raddif;
    Segment seg;
 
@@ -761,11 +765,11 @@ void PMSphereSweep::setCurved( bool cubic )
       seg.points.clear( );
       seg.radii.clear( );
       seg.direction.clear( );
-      raddif = ( m_radii[i + 2] - m_radii[i + 1] ) / ( s_sSteps - 1.0 );
+      raddif = ( m_radii[i + 2] - m_radii[i + 1] ) / ( sSteps - 1.0 );
       for ( int j = 0; j < 4; ++j )
          centres[j] = m_points[ i + j ];
 
-      for ( int j = 0; j < s_sSteps; ++j )
+      for ( int j = 0; j < sSteps; ++j )
       {
          if ( cubic )
             seg.points.append( catmullRom( centres, ( divs * j ) ) );
@@ -776,14 +780,14 @@ void PMSphereSweep::setCurved( bool cubic )
       }
 
       seg.direction.append( seg.points[0] - seg.points[1] );
-      for ( int j = 1; j < ( s_sSteps - 1 ) ; ++ j )
+      for ( int j = 1; j < ( sSteps - 1 ) ; ++ j )
       {
          vtr = seg.points[ j - 1 ] - seg.points[j];
          vtr += seg.points[j] - seg.points[ j + 1 ];
          seg.direction.append( vtr );
       }
-      seg.direction.append( seg.points[ s_sSteps - 2 ] -
-                            seg.points[ s_sSteps - 1 ] );
+      seg.direction.append( seg.points[ sSteps - 2 ] -
+                            seg.points[ sSteps - 1 ] );
 
       m_segments.append( seg );
    }
@@ -851,7 +855,7 @@ PMVector PMSphereSweep::bSpline( PMVector *v, double t )
    return rst;
 }
 
-void PMSphereSweep::createSphere( PMVector v, double r )
+void PMSphereSweep::createSphere( PMVector v, double r, int rSteps )
 {
    PMPointArray& points = m_pViewStructure->points( );
    PMLineArray& lines = m_pViewStructure->lines( );
@@ -859,29 +863,29 @@ void PMSphereSweep::createSphere( PMVector v, double r )
    PMVector point = PMVector( 0, 1, 0 ) * r;
    int pointUp = m_nextPoint++;
    int pointDown = m_nextPoint++;
-   double rotVal1 = M_PI / ( s_rSteps - 1 );
-   double rotVal2 = ( M_PI / s_rSteps ) * 2;
+   double rotVal1 = M_PI / ( rSteps - 1 );
+   double rotVal2 = ( M_PI / rSteps ) * 2;
 
    points[pointUp] = PMPoint ( point + v );
    points[pointDown] = PMPoint ( ( PMMatrix::rotation( 0, 0, M_PI ) * point ) + v );
 
 
-   for ( int i = 0; i < s_rSteps; ++i )
+   for ( int i = 0; i < rSteps; ++i )
    {
       lines[ m_nextLine++] = PMLine( pointUp, m_nextPoint );
-      for ( int j = 1; j < ( s_rSteps - 1 ); ++j )
+      for ( int j = 1; j < ( rSteps - 1 ); ++j )
       {
          points[m_nextPoint++] = PMPoint(
             ( PMMatrix::rotation( ( rotVal1 * j ), ( rotVal2 * i ), 0 ) * point ) + v );
 
-         if ( i < ( s_rSteps - 1 ) )
+         if ( i < ( rSteps - 1 ) )
             lines[m_nextLine++] = PMLine( m_nextPoint - 1, m_nextPoint +
-               s_rSteps - 3 );
+               rSteps - 3 );
          else
             lines[m_nextLine++] = PMLine( m_nextPoint - 1, m_nextPoint -
-               ( ( s_rSteps - 1 ) * ( s_rSteps - 2 ) ) - 1 );
+               ( ( rSteps - 1 ) * ( rSteps - 2 ) ) - 1 );
 
-         if ( j < ( s_rSteps - 2 ) )
+         if ( j < ( rSteps - 2 ) )
             lines[m_nextLine++] = PMLine( m_nextPoint - 1, m_nextPoint );
          else
             lines[m_nextLine++] = PMLine( m_nextPoint - 1, pointDown );
