@@ -1,22 +1,21 @@
-/***************************************************************************
-	     kscanoption.cpp -  Scanner option class
-                             -------------------
-    begin                : Wed Oct 13 2000
-    copyright            : (C) 2000 by Klaas Freitag
-    email                : Klaas.Freitag@SuSE.de
+/* This file is part of the KDE Project
+   Copyright (C) 2000 Klaas Freitag <freitag@suse.de>  
 
-    $Id: kscanoption.cpp,v 1.14 2001/07/22 10:24:03 pfeiffer Exp $
- ***************************************************************************/
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
+   You should have received a copy of the GNU Library General Public License
+   along with this library; see the file COPYING.LIB.  If not, write to
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
+*/
 
 #include <stdlib.h>
 #include <qwidget.h>
@@ -30,8 +29,7 @@
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qimage.h>
-#include <qfileinfo.h>
-#include <qapplication.h>
+#include <qregexp.h>
 
 #include <kdebug.h>
 
@@ -45,34 +43,23 @@
 // #define MIN_PREVIEW_DPI 20
 // this is nowhere used!? Additionally, it's defined to 75 in kscandevice.cpp
 
-/* switch to show some from time to time usefull alloc-messages */
+/* switch to show some from time to time useful alloc-messages */
 #undef MEM_DEBUG
 
 #undef APPLY_IN_SITU
 
-// global device list
 
 
-/**  Not really pretty to have these global variables in a lib.
- *   Should be solved by KScanOption being a friend to KScanDevice ?
- *   TODO
- **/
-bool        scanner_initialised = false;
-SANE_Handle scanner_handle      = 0;
-QAsciiDict<int>  option_dic;
-
-extern KScanOptSet gammaTables;
-
 /** inline-access to the option descriptor, object to changes with global vars. **/
 inline const SANE_Option_Descriptor *getOptionDesc( const QCString& name )
 {
-   int *idx = option_dic[ name ];
+   int *idx = (*KScanDevice::option_dic)[ name ];
    
    const SANE_Option_Descriptor *d = 0;
    // debug( "<< for option %s >>", name );
    if ( idx && *idx > 0 )
    {
-      d = sane_get_option_descriptor( scanner_handle, *idx );
+      d = sane_get_option_descriptor( KScanDevice::scanner_handle, *idx );
       // debug( "retrieving Option %s", d->name );
    }
    else
@@ -95,11 +82,11 @@ KScanOption::KScanOption( const QCString& new_name ) :
 {
    if( initOption( new_name ) )
    {
-      int  *num = option_dic[ getName() ];	
+      int  *num = (*KScanDevice::option_dic)[ getName() ];	
       if( !num || !buffer )
 	 return;
 
-      SANE_Status sane_stat = sane_control_option( scanner_handle, *num,
+      SANE_Status sane_stat = sane_control_option( KScanDevice::scanner_handle, *num,
 						   SANE_ACTION_GET_VALUE,
 						   buffer, 0 );
 
@@ -152,7 +139,7 @@ bool KScanOption::initOption( const QCString& new_name )
 	        buffer = 0;
   	}
 
-	KScanOption *gtOption = gammaTables[ new_name ];
+	KScanOption *gtOption = (*KScanDevice::gammaTables)[ new_name ];
 	if( gtOption )
 	{
 	   kdDebug(29000) << "Is older GammaTable!" << endl;
@@ -169,7 +156,7 @@ bool KScanOption::initOption( const QCString& new_name )
 	}
     }
 
-   return( desc > 0 );
+   return desc;
 }
 
 KScanOption::KScanOption( const KScanOption &so ) :
@@ -183,11 +170,21 @@ KScanOption::KScanOption( const KScanOption &so ) :
    brightness = so.brightness;
    contrast = so.contrast;
 
-   if( so.buffer_untouched ) kdDebug(29000) << "Buffer of source is untouched!" << endl;
-   // debug("Here Duplication for %s, reserving %d bytes", (const char*)  name, desc->size );
+   /* intialise */
+   buffer = 0;
+   buffer_size = 0;
 
-   /* the widget si not copied ! */
+   /* the widget is not copied ! */
    internal_widget = 0;
+   
+   if( ! ( desc && name ) )
+   {
+      kdWarning( 29000) << "Trying to copy a not healthy option (no name nor desc)" << endl;
+      return;
+   }
+   
+   if( so.buffer_untouched )
+      kdDebug(29000) << "Buffer of source is untouched!" << endl;
 
    switch( desc->type )
    {
@@ -203,9 +200,8 @@ KScanOption::KScanOption( const KScanOption &so ) :
  	    memcpy( buffer, so.buffer,  buffer_size );
        break;
        default:
-            buffer = 0;
-            buffer_size = 0;
-
+	  kdWarning( 29000 ) << "unknown option type in copy constructor" << endl;
+	  break;
     }
 }
 
@@ -233,7 +229,10 @@ const KScanOption& KScanOption::operator= (const KScanOption& so )
    delete internal_widget;
    internal_widget = so.internal_widget;
 
-   if( buffer ) delete( (char*)buffer);
+   if( buffer ) {
+      delete [] buffer;
+      buffer = 0;
+   }
 
    switch( desc->type )
    {
@@ -341,7 +340,7 @@ void KScanOption::slRedrawWidget( KScanOption *so )
 
 void KScanOption::slReload( void )
 {
-   int  *num = option_dic[ getName() ];	
+   int  *num = (*KScanDevice::option_dic)[ getName() ];	
    desc = getOptionDesc( getName() );	
 	
    if( !desc || !num  )
@@ -387,29 +386,27 @@ void KScanOption::slReload( void )
 	    }
       }
    }
-#if 0	
+
    if( active())
    {
       if( (size_t) desc->size > buffer_size )
       {
-	 qDebug( "SERIOUS ERROR: Buffer to small: %d (required) - %d %s !",
-		desc->size, buffer_size, (const char*) name );
-      }
-  			
-      SANE_Status sane_stat = sane_control_option( scanner_handle, *num,
-						   SANE_ACTION_GET_VALUE, buffer, 0 );
-
-      if( sane_stat != SANE_STATUS_GOOD )
-      {
-	 kdDebug(29000) << "ERROR: Cant get value for " << getName() << ": " << sane_strstatus( sane_stat ) << endl;
+	 kdDebug(29000) << "ERROR: Buffer to small" << endl;
       }
       else
       {
-	 buffer_untouched = false;
-	 kdDebug(29000) << "Setting buffer untouched to FALSE" << endl;
+	 SANE_Status sane_stat = sane_control_option( KScanDevice::scanner_handle, *num,
+						      SANE_ACTION_GET_VALUE, buffer, 0 );
+
+	 if( sane_stat != SANE_STATUS_GOOD )
+	 {
+	    kdDebug(29000) << "ERROR: Cant get value for " << getName() << ": " << sane_strstatus( sane_stat ) << endl;
+	 } else {
+	    buffer_untouched = false;
+	    kdDebug(29000) << "Setting buffer untouched to FALSE" << endl;
+	 }
       }
    }
-#endif
 }
 
 
@@ -418,7 +415,6 @@ KScanOption::~KScanOption()
 #ifdef MEM_DEBUG
    qDebug( "M: FREEing %d byte of option <%s>", buffer_size, (const char*) getName());
 #endif
-   if( buffer ) delete ( (char*) buffer );
 }
 
 bool KScanOption::valid( void ) const
@@ -523,7 +519,7 @@ bool KScanOption::set( int val )
    bool ret = false;
 
    int word_size       = 0;
-   QArray<SANE_Word> qa;
+   QMemArray<SANE_Word> qa;
    SANE_Word sw        = SANE_TRUE;
    const SANE_Word sw1 = val;
    const SANE_Word sw2 = SANE_FIX( (double) val );
@@ -589,7 +585,7 @@ bool KScanOption::set( double val )
    if( ! desc ) return( false );
    bool ret = false;
    int  word_size = 0;
-   QArray<SANE_Word> qa;
+   QMemArray<SANE_Word> qa;
    SANE_Word sw = SANE_FALSE;
 
    switch( desc->type )
@@ -657,7 +653,7 @@ bool KScanOption::set( int *val, int size )
     int    offset = 0;
 
     int word_size = desc->size / sizeof( SANE_Word ); /* add 1 in case offset is needed */
-    QArray<SANE_Word> qa( 1+word_size );
+    QMemArray<SANE_Word> qa( 1+word_size );
 #if 0
     if( desc->constraint_type == SANE_CONSTRAINT_WORD_LIST )
     {
@@ -730,6 +726,28 @@ bool KScanOption::set( const QCString& c_string )
    
    if( ! desc ) return( false );
 
+   /* Check if it is a gammatable. If it is, convert to KGammaTable and call
+    *  the approbiate set method.
+    */
+   QRegExp re( "\\d+, \\d+, \\d+" );
+   re.setMinimal(true);
+   
+   if( QString(c_string).contains( re ))
+   {
+      QStringList relist = QStringList::split( ", ", QString(c_string) );
+      
+      int brig = (relist[0]).toInt();
+      int contr = (relist[1]).toInt();
+      int gamm = (relist[2]).toInt();
+
+      KGammaTable gt( brig, contr, gamm );
+      ret = set( &gt );
+      kdDebug(29000) << "Setting GammaTable with int vals " << brig << "|" << contr << "|" << gamm << endl;
+      
+      return( ret );
+   }
+
+   
    /* On String-type the buffer gets malloced in Constructor */
    switch( desc->type )
    {
@@ -757,6 +775,12 @@ bool KScanOption::set( const QCString& c_string )
 	       kdDebug(29000) << "Conversion of string value failed!" << endl;
 	   
 	   break;
+      case SANE_TYPE_BOOL:
+	 kdDebug(29000) << "Type is BOOL, setting value <" << c_string << ">" << endl;
+	 val = 0;
+	 if( c_string == "true" ) val = 1;
+	 set( val );
+	 break;
        default:
 	   kdDebug(29000) << "Type of " << name << " is " << desc->type << endl;
 	   kdDebug(29000) << "Cant set " << name << " with type string" << endl;
@@ -786,8 +810,8 @@ bool KScanOption::set( KGammaTable *gt )
    SANE_Word *run = gt->getTable();
 
    int word_size = desc->size / sizeof( SANE_Word );
-   QArray<SANE_Word> qa( word_size );
-
+   QMemArray<SANE_Word> qa( word_size );
+   kdDebug(29000) << "KScanOption::set for Gammatable !" << endl;
    switch( desc->type )
    {
       case SANE_TYPE_INT:
@@ -970,12 +994,53 @@ QStrList KScanOption::getList( ) const
 }
 
 
+
+bool KScanOption::getRangeFromList( double *min, double *max, double *q ) const
+{
+   if( !desc ) return( false );
+   bool ret = true;
+
+   if ( desc->constraint_type == SANE_CONSTRAINT_WORD_LIST ) {
+	    // Try to read resolutions from word list
+	    kdDebug(29000) << "Resolutions are in a word list" << endl;
+            const SANE_Int *sint =  desc->constraint.word_list;
+            int amount_vals = *sint; sint ++;
+	    double value;
+	    *min = 0;
+	    *max = 0;
+	    *q = -1; // What is q?
+
+            for( int i=0; i < amount_vals; i++ ) {
+		if( desc->type == SANE_TYPE_FIXED ) {
+		    value = (double) SANE_UNFIX( *sint );
+		} else {
+		    value = *sint;
+		}
+		if ((*min > value) || (*min == 0)) *min = value;
+		if ((*max < value) || (*max == 0)) *max = value;
+		
+		if( min != 0 && max != 0 && max > min ) {
+		    double newq = max - min;
+		    *q = newq;
+		}
+		sint++;
+            }
+   } else {
+      kdDebug(29000) << "getRangeFromList: No list type " << desc->name << endl;
+      ret = false;
+    }
+    return( ret );
+}
+
+
+
 bool KScanOption::getRange( double *min, double *max, double *q ) const
 {
    if( !desc ) return( false );
    bool ret = true;
 
-   if( desc->constraint_type == SANE_CONSTRAINT_RANGE) {
+   if( desc->constraint_type == SANE_CONSTRAINT_RANGE ||
+	   desc->constraint_type == SANE_CONSTRAINT_WORD_LIST ) {
       const SANE_Range *r = desc->constraint.range;
 
       if( desc->type == SANE_TYPE_FIXED ) {
@@ -998,7 +1063,11 @@ QWidget *KScanOption::createWidget( QWidget *parent, const QString& w_desc,
                                     const QString& tooltip )
 {
   QStrList list;
-  if( ! valid() ) return( 0 );
+  if( ! valid() )
+  {
+     kdDebug(29000) << "The option is not valid!" << endl;
+     return( 0 );
+  }
   QWidget *w = 0;
   /* free the old widget */
   delete internal_widget;
@@ -1022,6 +1091,7 @@ QWidget *KScanOption::createWidget( QWidget *parent, const QString& w_desc,
     case SINGLE_VAL:
       /* Widget Type is Entry-Field */
       w = 0; // new QEntryField(
+      kdDebug(29000) << "can not create widget for SINGLE_VAL!" << endl;
       break;
     case RANGE:
       /* Widget Type is Slider */
@@ -1030,6 +1100,7 @@ QWidget *KScanOption::createWidget( QWidget *parent, const QString& w_desc,
     case GAMMA_TABLE:
       /* Widget Type is Slider */
       // w = KSaneSlider( parent, text );
+      kdDebug(29000) << "can not create widget for GAMMA_TABLE!" << endl;
       w = 0; // No widget, needs to be a set !
       break;
     case STR_LIST:	 		
@@ -1041,6 +1112,7 @@ QWidget *KScanOption::createWidget( QWidget *parent, const QString& w_desc,
       /* Widget Type is Selection Box */
       break;
     default:
+       kdDebug(29000) << "returning zero for default widget creation!" << endl;
       w  = 0;
       break;
     }
@@ -1126,12 +1198,12 @@ void *KScanOption::allocBuffer( long size )
 bool KScanOption::applyVal( void )
 {
    bool res = true;
-   int *idx = option_dic[ name ];
+   int *idx = (*KScanDevice::option_dic)[ name ];
 
    if( *idx == 0 ) return( false );
    if( ! buffer )  return( false );
 
-   SANE_Status stat = sane_control_option ( scanner_handle, *idx,
+   SANE_Status stat = sane_control_option ( KScanDevice::scanner_handle, *idx,
 					    SANE_ACTION_SET_VALUE, buffer,
 					    0 );
    if( stat != SANE_STATUS_GOOD )
